==> zio-aws-ec2_2.12-5.17.152.1-sources.jar: zio/aws/ec2/model/GetTransitGatewayAttachmentPropagationsResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetTransitGatewayAttachmentPropagationsResponse(
    transitGatewayAttachmentPropagations: Option[
      Iterable[zio.aws.ec2.model.TransitGatewayAttachmentPropagation]
    ] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetTransitGatewayAttachmentPropagationsResponse = {
    import GetTransitGatewayAttachmentPropagationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetTransitGatewayAttachmentPropagationsResponse
      .builder()
      .optionallyWith(
        transitGatewayAttachmentPropagations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.transitGatewayAttachmentPropagations)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.GetTransitGatewayAttachmentPropagationsResponse.ReadOnly =
    zio.aws.ec2.model.GetTransitGatewayAttachmentPropagationsResponse
      .wrap(buildAwsValue())
}
object GetTransitGatewayAttachmentPropagationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetTransitGatewayAttachmentPropagationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.GetTransitGatewayAttachmentPropagationsResponse =
      zio.aws.ec2.model.GetTransitGatewayAttachmentPropagationsResponse(
        transitGatewayAttachmentPropagations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def transitGatewayAttachmentPropagations: Option[
      List[zio.aws.ec2.model.TransitGatewayAttachmentPropagation.ReadOnly]
    ]
    def nextToken: Option[String]
    def getTransitGatewayAttachmentPropagations: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.TransitGatewayAttachmentPropagation.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "transitGatewayAttachmentPropagations",
      transitGatewayAttachmentPropagations
    )
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetTransitGatewayAttachmentPropagationsResponse
  ) extends zio.aws.ec2.model.GetTransitGatewayAttachmentPropagationsResponse.ReadOnly {
    override val transitGatewayAttachmentPropagations: Option[
      List[zio.aws.ec2.model.TransitGatewayAttachmentPropagation.ReadOnly]
    ] = scala
      .Option(impl.transitGatewayAttachmentPropagations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.TransitGatewayAttachmentPropagation.wrap(item)
        }.toList
      )
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetTransitGatewayAttachmentPropagationsResponse
  ): zio.aws.ec2.model.GetTransitGatewayAttachmentPropagationsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.12-5.19.7.2-sources.jar: zio/aws/ec2/model/GetTransitGatewayAttachmentPropagationsResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetTransitGatewayAttachmentPropagationsResponse(
    transitGatewayAttachmentPropagations: Optional[
      Iterable[zio.aws.ec2.model.TransitGatewayAttachmentPropagation]
    ] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetTransitGatewayAttachmentPropagationsResponse = {
    import GetTransitGatewayAttachmentPropagationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetTransitGatewayAttachmentPropagationsResponse
      .builder()
      .optionallyWith(
        transitGatewayAttachmentPropagations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.transitGatewayAttachmentPropagations)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.GetTransitGatewayAttachmentPropagationsResponse.ReadOnly =
    zio.aws.ec2.model.GetTransitGatewayAttachmentPropagationsResponse
      .wrap(buildAwsValue())
}
object GetTransitGatewayAttachmentPropagationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetTransitGatewayAttachmentPropagationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.GetTransitGatewayAttachmentPropagationsResponse =
      zio.aws.ec2.model.GetTransitGatewayAttachmentPropagationsResponse(
        transitGatewayAttachmentPropagations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def transitGatewayAttachmentPropagations: Optional[
      List[zio.aws.ec2.model.TransitGatewayAttachmentPropagation.ReadOnly]
    ]
    def nextToken: Optional[String]
    def getTransitGatewayAttachmentPropagations: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.TransitGatewayAttachmentPropagation.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "transitGatewayAttachmentPropagations",
      transitGatewayAttachmentPropagations
    )
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetTransitGatewayAttachmentPropagationsResponse
  ) extends zio.aws.ec2.model.GetTransitGatewayAttachmentPropagationsResponse.ReadOnly {
    override val transitGatewayAttachmentPropagations: Optional[
      List[zio.aws.ec2.model.TransitGatewayAttachmentPropagation.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.transitGatewayAttachmentPropagations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.TransitGatewayAttachmentPropagation.wrap(item)
        }.toList
      )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetTransitGatewayAttachmentPropagationsResponse
  ): zio.aws.ec2.model.GetTransitGatewayAttachmentPropagationsResponse.ReadOnly =
    new Wrapper(impl)
}
